==> basic_ui-0.1.0.tar.gz: lib/src/widgets/basic_list.dart <==
import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

import '../models/basic_theme.dart';

/// Creates a list "items" separated by [Divider].
///
/// This Widget is appropriate for list views with a small number of item
/// and separator children.
///
/// This Widget dont have scroll container.
class BasicList extends HookWidget {
  const BasicList({
    Key? key,
    required this.itemCount,
    required this.itemBuilder,
    this.disableDivider = false,
    this.padding,
  }) : super(key: key);

  /// Number of items in list view.
  final int itemCount;

  /// Build Widget to display in list view.
  final Widget Function(BuildContext context, int index) itemBuilder;

  /// Set to true to disable divider.
  final bool disableDivider;

  /// The empty space that surrounds the list view.
  final EdgeInsetsGeometry? padding;

  List<Widget> buildItem(BuildContext context, BasicTheme themeProviderState) {
    final List<Widget> widgets = [];

    for (int i = 0; i < itemCount; i++) {
      widgets.add(itemBuilder(context, i));
      if (i != itemCount - 1 && !disableDivider) {
        widgets.add(Divider(color: themeProviderState.borderColor));
      }
    }
    return widgets;
  }

  @override
  Widget build(BuildContext context) {
    final theme = useProvider(themeProvider).theme;

    return Container(
      padding: padding,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: buildItem(context, theme),
      ),
    );
  }
}

==> basic_ui-0.2.2.tar.gz: lib/src/widgets/basic_list.dart <==
import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

import '../models/basic_theme.dart';

/// Creates a list "items" separated by [Divider].
///
/// This Widget is appropriate for list views with a small number of item
/// and separator children.
///
/// This Widget dont have scroll container.
class BasicList extends HookWidget {
  const BasicList({
    Key? key,
    required this.itemCount,
    required this.itemBuilder,
    this.enableDivider = true,
    this.padding,
  }) : super(key: key);

  /// Number of items in list view.
  final int itemCount;

  /// Build Widget to display in list view.
  final Widget Function(BuildContext context, int index) itemBuilder;

  /// Set to true to enable divider.
  final bool enableDivider;

  /// The empty space that surrounds the list view.
  final EdgeInsetsGeometry? padding;

  List<Widget> buildItem(BuildContext context, BasicTheme themeProviderState) {
    final List<Widget> widgets = [];

    for (int i = 0; i < itemCount; i++) {
      widgets.add(itemBuilder(context, i));
      if (i != itemCount - 1 && enableDivider) {
        widgets.add(Divider(color: themeProviderState.borderColor));
      }
    }
    return widgets;
  }

  @override
  Widget build(BuildContext context) {
    final theme = useProvider(themeProvider).theme;

    return Container(
      padding: padding,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: buildItem(context, theme),
      ),
    );
  }
}
